@@ -919,6 +919,20 @@ class QueryGenerator {
 				$fieldSqlList[$index] = $fieldSql;
 			}
 		}
+
+		$currentUserModel = Users_Record_Model::getCurrentUserModel();
+		if(($baseModule == 'Calendar' || $baseModule == 'Events') && !$currentUserModel->isAdminUser()) {
+			$moduleFocus = CRMEntity::getInstance('Calendar');
+			$condition = $moduleFocus->buildWhereClauseConditionForCalendar();
+			if ($condition) {
+				if ($this->conditionInstanceCount > 0) {
+					$sql .= $condition . ' AND ';
+				} else {
+					$sql .= ' AND ' . $condition;
+				}
+			}
+		}
+		
 		// This is needed as there can be condition in different order and there is an assumption in makeGroupSqlReplacements API
 		// that it expects the array in an order and then replaces the sql with its the corresponding place
 		ksort($fieldSqlList);
@@ -1140,7 +1154,7 @@ class QueryGenerator {
 				$value = "'$value'";
 			}
 
-			if($this->isNumericType($field->getFieldDataType()) && empty($value)) {
+			if(($this->isNumericType($field->getFieldDataType())) && empty($value)) {				
 				$value = '0';
 			}
 			$sql[] = "$sqlOperator $value";
@@ -1404,19 +1418,19 @@ class QueryGenerator {
 
 	public function getDashBoardConditionList() {
 		if(isset($_REQUEST['leadsource'])) {
-			$leadSource = $_REQUEST['leadsource'];
+			$leadSource = vtlib_purify($_REQUEST['leadsource']);
 		}
 		if(isset($_REQUEST['date_closed'])) {
-			$dateClosed = $_REQUEST['date_closed'];
+			$dateClosed = vtlib_purify($_REQUEST['date_closed']);
 		}
 		if(isset($_REQUEST['sales_stage'])) {
-			$salesStage = $_REQUEST['sales_stage'];
+			$salesStage = vtlib_purify($_REQUEST['sales_stage']);
 		}
 		if(isset($_REQUEST['closingdate_start'])) {
-			$dateClosedStart = $_REQUEST['closingdate_start'];
+			$dateClosedStart = vtlib_purify($_REQUEST['closingdate_start']);
 		}
 		if(isset($_REQUEST['closingdate_end'])) {
-			$dateClosedEnd = $_REQUEST['closingdate_end'];
+			$dateClosedEnd = vtlib_purify($_REQUEST['closingdate_end']);
 		}
 		if(isset($_REQUEST['owner'])) {
 			$owner = vtlib_purify($_REQUEST['owner']);
@@ -1512,4 +1526,4 @@ class QueryGenerator {
 	}
 
 }
-?>
\ No newline at end of file
+?>
