@@ -1164,6 +1164,7 @@ $languageStrings = array(
 	'LBL_MARKETING' => 'MARKETING',
 	'LBL_SALES' => 'SALES',
 	'LBL_PROJECT' => 'PROJECTS',
+	'LBL_TOOLS' => 'TOOLS',
 	'LBL_TAGS' => 'Tags',
 	'LBL_SHARE_TAGS' => 'Public Tags',
 	'LBL_SHARE_TAG' => 'Shared Tag(s)',
@@ -1282,12 +1283,11 @@ $languageStrings = array(
 	'LBL_REVOKE_ACCESS' => 'Revoke Access',
 	'GOOGLE_REVOKE_ACCESS_MESSAGE' => 'Clicking on this will remove existing Google authentication for Contacts and Calendar. It will not delete any records which are already synchronized.',
 	'OFFICE_REVOKE_ACCESS_MESSAGE' => 'Clicking on this will remove existing Office365 authentication for Contacts, Calendar and Emails. It will not delete any records which are already synchronized.',
-	'LBL_EMAIL_DOMAIN_HELPTEXT' => 'Email Domain field will be used to match Cases and Contacts created from Emails. For example, if a new support email comes from john@apple.com, it would be linked to Organization that has apple.com in the Email domain field. Multiple domains should be separated by commas',
 	'LBL_START_GUIDED_TOUR' => 'Start Guided Tour',
 	'LBL_MENU' => 'Menu',
 	'LBL_EMAIL_DOMAIN_HELPTEXT'=>'Email Domain field will be used to match Cases and Contacts created from Emails. '
-	. 'For example, if a new support email comes from john@apple.com, it would be linked to Organization that has '
-	. 'apple.com in the Email domain field. Multiple domains should be separated by commas',
+	. 'For example, if a new support email comes from john@company.com, it would be linked to Organization that has '
+	. 'company.com in the Email domain field. Multiple domains should be separated by commas',
 
 	'LBL_SHARED_LIST_NON_ADMIN_MESSAGE' => 'This is a Shared list. Please contact your CRM Administrator to configure columns for All list',
 	'LBL_SHARED_LIST_OWNER_MESSAGE' => 'This is a shared list. Please contact %s to change the columns of this list',
@@ -1387,6 +1387,8 @@ $languageStrings = array(
 	'LBL_RECENT_UPDATES' => 'Recent Updates',
 	'LBL_VIEW_UPDATES_IN_DETAIL' => 'Read More ...',
 	'LBL_DEFAULT_DASHBOARD_TOOLTIP'=>'Make this dashboard as default by reordering it as the first tab!',
+	'LBL_RELATED_MODULES_PERMISSION_DENIED' => 'Related modules permission is denied',
+	'LBL_RECORD_PERMISSION_DENIED' => 'Record permissions denied',
 );
 
 $jsLanguageStrings = array(
@@ -1645,7 +1647,6 @@ $jsLanguageStrings = array(
 	'JS_FUTURE_EVENT_CANNOT_BE_HELD' => 'Cannot Be Held For Future',
 	'LBL_WARNING' => 'Warning',
 	'DELETE_USER_PERMANENT_WARNING' => 'Deleting a user permanently will transfer all records including comments and history to new user.',
-	'JS_CLOSE' => 'Close',
 	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_FUTURE_EVENT_CANNOT_BE_HELD' => 'Cannot Be Held For Future',
 	'JS_CLOSE' => 'Close',
@@ -1713,8 +1714,6 @@ $jsLanguageStrings = array(
 	'JS_SELECTED_LEAD_DOES_NOT_HAVE_AN_ADDRESS' => 'Selected Lead does not contain address to copy',
 	'JS_INVALID_EMAILS' => 'Invalid Emails',
 	'JS_DIRECTORY_IS_EMPTY' => 'Directory is empty',
-	'JS_INTERNAL_COMMENT' => 'Internal Comment',
-	'JS_INTERNAL_COMMENT_INFO' => 'The comment will only be seen by CRM users, if the internal comment checkbox is enabled. To notify customers (through configurable workflows or customer portal) leave this checkbox disabled',
 	'JS_NO_LINE_ITEM' =>'Line items cannot be empty.',
 	'JS_INTERNAL_COMMENT' => 'Internal Comment',
 	'JS_INTERNAL_COMMENT_INFO' => 'The comment will only be seen by CRM users, if the internal comment checkbox is enabled. To notify customers (through configurable workflows or customer portal) leave this checkbox disabled',
@@ -1936,4 +1935,6 @@ $jsLanguageStrings = array(
 	'JS_SET_DEFAULT_TAB' => 'is set as your default dashboard',
 	'JS_PASSWORD_MISMATCH_ERROR' => 'Please re-enter passwords. The "new password" and "confirm password" values do not match.',
 	'LBL_LIST_DELETE_CONFIRMATION' => 'Are you sure you want to delete?',
-);
\ No newline at end of file
+	'JS_WIDGET_RESIZING_WAIT_MSG' => 'Widget contents will load after resizing.',
+        'JS_COPIED_SUCCESSFULLY' => 'Copied successfully',
+);
