@@ -26,16 +26,44 @@ class Vtiger_Detail_View extends Vtiger_Index_View {
 		$this->exposeMethod('showRelatedRecords');
 	}
 
+	public function requiresPermission(Vtiger_Request $request){
+		$permissions = parent::requiresPermission($request);
+		$mode = $request->getMode();
+		$permissions[] = array('module_parameter' => 'module', 'action' => 'DetailView', 'record_parameter' => 'record');
+		if(!empty($mode)) {
+			switch ($mode) {
+				case 'showModuleDetailView':
+				case 'showModuleSummaryView':
+				case 'showModuleBasicView':
+					$permissions[] = array('module_parameter' => 'module', 'action' => 'DetailView', 'record_parameter' => 'record');
+					break;
+				case 'showRecentComments':
+				case 'showChildComments':
+					$permissions[] = array('module_parameter' => 'custom_module', 'action' => 'DetailView');
+					$request->set('custom_module', 'ModComments');
+					break;
+				case 'showRelatedList':
+				case 'showRelatedRecords':
+					$permissions[] = array('module_parameter' => 'relatedModule', 'action' => 'DetailView');
+					break;
+				case 'getActivities':
+					$permissions[] = array('module_parameter' => 'custom_module', 'action' => 'DetailView');
+					$request->set('custom_module', 'Calendar');
+					break;
+				default:
+					break;
+			}
+		}
+		return $permissions;
+	}
+	
 	function checkPermission(Vtiger_Request $request) {
+        parent::checkPermission($request);
 		$moduleName = $request->getModule();
 		$recordId = $request->get('record');
 
-		$recordPermission = Users_Privileges_Model::isPermitted($moduleName, 'DetailView', $recordId);
-		if(!$recordPermission) {
-			throw new AppException(vtranslate('LBL_PERMISSION_DENIED'));
-		}
-
-		if ($recordId) {
+		$nonEntityModules = array('Users', 'Events', 'Calendar', 'Portal', 'Reports', 'Rss', 'EmailTemplates');
+		if ($recordId && !in_array($moduleName, $nonEntityModules)) {
 			$recordEntityName = getSalesEntityType($recordId);
 			if ($recordEntityName !== $moduleName) {
 				throw new AppException(vtranslate('LBL_PERMISSION_DENIED'));
@@ -129,11 +157,7 @@ class Vtiger_Detail_View extends Vtiger_Index_View {
 		$allUserTags = Vtiger_Tag_Model::getAllUserTags($currentUserModel->getId());
 		$viewer->assign('TAGS_LIST', $tagsList);
 		$viewer->assign('ALL_USER_TAGS', $allUserTags);
-
-		$appName = $request->get('app');
-		if(!empty($appName)){
-			$viewer->assign('SELECTED_MENU_CATEGORY',$appName);
-		}
+		$viewer->assign('SELECTED_MENU_CATEGORY', 'MARKETING');
 
 		$selectedTabLabel = $request->get('tab_label');
 		$relationId = $request->get('relationId');
@@ -412,6 +436,16 @@ class Vtiger_Detail_View extends Vtiger_Index_View {
 		$recordModel = Vtiger_Record_Model::getInstanceById($parentRecordId);
 		$viewer = $this->getViewer($request);
 		$viewer->assign('SOURCE',$recordModel->get('source'));
+        $recentActivities = ModTracker_Record_Model::getUpdates($parentRecordId, $pagingModel,$moduleName);
+
+        $totalCount = ModTracker_Record_Model::getTotalRecordCount($parentRecordId);
+        $pageLimit = $pagingModel->getPageLimit();
+        $pageCount = ceil((int) $totalCount / (int) $pageLimit);
+        if($pageCount - $pagingModel->getCurrentPage() == 0) {
+            $pagingModel->set('nextPageExists', false);
+        } else {
+            $pagingModel->set('nextPageExists', true);
+        }
 		$viewer->assign('RECENT_ACTIVITIES', $recentActivities);
 		$viewer->assign('MODULE_NAME', $moduleName);
 		$viewer->assign('PAGING_MODEL', $pagingModel);
@@ -520,7 +554,9 @@ class Vtiger_Detail_View extends Vtiger_Index_View {
 		}
 		if($targetControllerClass) {
 			$targetController = new $targetControllerClass();
-			return $targetController->process($request);
+			if($targetController->checkPermission($request)){
+				return $targetController->process($request);
+			}
 		}
 	}
 
