@@ -729,6 +729,8 @@ class Vtiger_Functions {
 
 	static function getSingleFieldValue($tablename, $fieldname, $idname, $id) {
 		global $adb;
+        $fieldname = Vtiger_Util_Helper::validateStringForSql($fieldname);
+        $idname = Vtiger_Util_Helper::validateStringForSql($idname);
 		$fieldval = $adb->query_result($adb->pquery("select $fieldname from $tablename where $idname = ?", array($id)), 0, $fieldname);
 		return $fieldval;
 	}
@@ -955,7 +957,8 @@ class Vtiger_Functions {
 
 	static function getPickListValuesFromTableForRole($tablename, $roleid) {
 		global $adb;
-		$query = "select $tablename from vtiger_$tablename inner join vtiger_role2picklist on vtiger_role2picklist.picklistvalueid = vtiger_$tablename.picklist_valueid where roleid=? and picklistid in (select picklistid from vtiger_picklist) order by sortid";
+        $tablename = Vtiger_Util_Helper::validateStringForSql($tablename);
+		$query = "select $tablename from vtiger_$tablename inner join vtiger_role2picklist on vtiger_role2picklist.picklistvalueid = vtiger_$tablename.picklist_valueid where roleid=? and picklistid in (select picklistid from vtiger_picklist) order by sortorderid";
 		$result = $adb->pquery($query, array($roleid));
 		$fldVal = Array();
 		while ($row = $adb->fetch_array($result)) {
@@ -1062,14 +1065,19 @@ class Vtiger_Functions {
 	/*
 	 * Function to generate encrypted password.
 	 */
-	static function generateEncryptedPassword($password, $mode='CRYPT') {
+	static function generateEncryptedPassword($password, $mode='') {
+		if ($mode == '') {
+			$mode = (version_compare(PHP_VERSION, '5.5.0') >= 0)? 'PHASH' : 'CRYPT';
+		}
+
+		if ($mode == 'PHASH') return password_hash($password, PASSWORD_DEFAULT);
 
 		if ($mode == 'MD5') return md5($password);
 
 		if ($mode == 'CRYPT') {
 			$salt = null;
 			if (function_exists('password_hash')) { // php 5.5+
-				$salt = password_hash();
+				$salt = password_hash($password, PASSWORD_DEFAULT);
 			} else {
 				$salt = '$2y$11$'.str_replace("+",".",substr(base64_encode(openssl_random_pseudo_bytes(17)),0,22));
 			}
@@ -1085,6 +1093,7 @@ class Vtiger_Functions {
 	static function compareEncryptedPassword($plainText, $encryptedPassword, $mode='CRYPT') {
 		$reEncryptedPassword = null;
 		switch ($mode) {
+			case 'PHASH': return password_verify($plainText, $encryptedPassword);
 			case 'CRYPT': $reEncryptedPassword = crypt($plainText, $encryptedPassword); break;
 			case 'MD5'  : $reEncryptedPassword = md5($plainText);	break;
 			default     : $reEncryptedPassword = $plainText;		break;
@@ -1320,11 +1329,7 @@ class Vtiger_Functions {
 	 * @return type -- table name
 	 */
 	public static function getUserSpecificTableName($moduleName) {
-		$moduleName = strtolower($moduleName);
-		if ($moduleName == "events") {
-			$moduleName = "calendar";
-		}
-		return "vtiger_".$moduleName.'_user_field';
+		return 'vtiger_crmentity_user_field';
 	}
 
 	/**
@@ -1374,6 +1379,36 @@ class Vtiger_Functions {
 		return $jwt;
 	}
 
+	/**
+	 * Function to mask input text.
+	 */
+	static function toProtectedText($text) {
+		if (empty($text)) return $text;
+
+		require_once 'include/utils/encryption.php';
+		$encryption = new Encryption();
+		return '$ve$'.$encryption->encrypt($text);
+	}
+	
+	/* 
+	 * Function to determine if text is masked.
+	 */
+	static function isProtectedText($text) {
+		return !empty($text) && (strpos($text, '$ve$') === 0);
+	}
+	
+	/*
+	 * Function to unmask the text.
+	 */
+	static function fromProtectedText($text) {
+		if (static::isProtectedText($text)) {
+			require_once 'include/utils/encryption.php';
+			$encryption = new Encryption();
+			return $encryption->decrypt(substr($text, 4));
+		}
+		return $text;
+	}
+
 	/*
 	 * Function to convert file size in bytes to user displayable format
 	 */
@@ -1408,4 +1443,87 @@ class Vtiger_Functions {
 		}
 		return $isRelated;
 	}
+
+	/**
+	 * Function to Escapes special characters in a string for use in an SQL statement
+	 * @param type $value
+	 * @return type
+	 */
+	static function realEscapeString($value){
+		$db = PearDatabase::getInstance();
+		$value = $db->sql_escape_string($value);
+		return $value;
+	}
+    
+    /**
+     * Request parameters and it's type.
+     * @var type 
+     */
+    protected static $type = array(
+	'record' => 'id',
+	'src_record' => 'id',
+	'parent_id' => 'id',
+        '_mfrom' => 'email',
+        '_mto' => 'email',
+        'sequencesList' => 'idlist',
+        'search_value' => 'keyword',
+    );
+
+    /**
+     * Function to validate request parameters.
+     * @param type $request
+     * @throws Exception - Bad Request
+     */
+    public static function validateRequestParameters($request) {
+        foreach (self::$type as $param => $type) {
+            if ( isset($request[$param])&& $request[$param] && !self::validateRequestParameter($type, $request[$param])) {
+                http_response_code(400);
+                throw new Exception('Bad Request');
+            }
+        }
+    }
+
+    /**
+     * Function to validate request parameter by it's type.
+     * @param  <String> type   - Type of paramter.
+     * @param  <String> $value - Which needs to be validated.
+     * @return <Boolean>
+     */
+    public static function validateRequestParameter($type, $value) {
+        $ok = true;
+        switch ($type) {
+            case 'id' : $ok = (preg_match('/[^0-9xH]/', $value)) ? false : $ok;
+                break;
+            case 'email' : $ok = (!filter_var($value, FILTER_VALIDATE_EMAIL)) ? false : $ok;
+                break;
+            case 'idlist' : $ok = (preg_match('/[a-zA-Z]/', $value)) ? false : $ok;
+                break;
+            case 'keyword':
+                $blackList = array('UNION', '--', 'SELECT ', 'SELECT*', '%', 'NULL', 'HEX');
+                foreach ($blackList as $keyword) {
+                    if (stripos($value, $keyword) !== false) {
+                        $ok = false;
+                        break;
+                    }
+                }
+                break;
+        }
+        return $ok;
+    }
+    
+    /**
+	 * Function to get file public url to access outside of CRM (from emails)
+	 * @param <Integer> $fileId
+	 * @param <String> $fileName
+	 * @return <String> $sourceUrl
+	 */
+	public static function getFilePublicURL($imageId, $imageName) {
+		$publicUrl = '';
+        $fileId = $imageId;
+        $fileName = $imageName;
+		if ($fileId) {
+			$publicUrl = "public.php?fid=$fileId&key=".$fileName;
+		}
+		return $publicUrl;
+	}
 }
